@@ -20,7 +20,7 @@ class CEA_Obj( object ):
         sonic_velocity_units='ft/sec', enthalpy_units='BTU/lbm', 
         density_units='lbm/cuft', specific_heat_units='BTU/lbm degR',
         viscosity_units='millipoise', thermal_cond_units='mcal/cm-K-s', 
-        fac_CR=None):
+        fac_CR=None, make_debug_prints=False):
         """::
         
         #: RocketCEA wraps the NASA FORTRAN CEA code to calculate Isp, cstar, and Tcomb
@@ -38,6 +38,7 @@ class CEA_Obj( object ):
         #: viscosity_units      = 'millipoise'   # lbf-sec/sqin, lbf-sec/sqft, lbm/ft-sec, poise, centipoise
         #: thermal_cond_units   = 'mcal/cm-K-s'  # millical/cm-degK-sec, BTU/hr-ft-degF, BTU/s-in-degF, cal/s-cm-degC, W/cm-degC
         #: fac_CR, Contraction Ratio of finite area combustor (None=infinite)
+        #: if make_debug_prints is True, print debugging info to terminal.
         """
 
         self.isp_units            = isp_units
@@ -68,7 +69,7 @@ class CEA_Obj( object ):
         
         self.cea_obj = CEA_Obj_default(propName=propName, oxName=oxName, fuelName=fuelName, 
                                useFastLookup=useFastLookup, makeOutput=makeOutput,
-                               fac_CR=fac_CR)
+                               fac_CR=fac_CR, make_debug_prints=make_debug_prints)
         self.desc = self.cea_obj.desc
     
     def get_IvacCstrTc(self, Pc=100.0, MR=1.0, eps=40.0):
@@ -200,18 +201,20 @@ class CEA_Obj( object ):
             hList[i] = self.enthalpy_U.dval_to_uval( H )
         
         return hList
-    def get_SpeciesMassFractions(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0):
+    def get_SpeciesMassFractions(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0,
+                                 min_fraction=0.000005):
         Pc = self.Pc_U.uval_to_dval( Pc ) # convert user units to psia
         
         molWtD, massFracD = self.cea_obj.get_SpeciesMassFractions(Pc=Pc, MR=MR, eps=eps, 
-                                                          frozenAtThroat=frozenAtThroat)
+                                        frozenAtThroat=frozenAtThroat,min_fraction=min_fraction)
         return molWtD, massFracD
 
-    def get_SpeciesMoleFractions(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0):
+    def get_SpeciesMoleFractions(self, Pc=100.0, MR=1.0,eps=40.0, frozen=0, frozenAtThroat=0,
+                                 min_fraction=0.000005):
         Pc = self.Pc_U.uval_to_dval( Pc ) # convert user units to psia
         
         molWtD, moleFracD = self.cea_obj.get_SpeciesMoleFractions(Pc=Pc, MR=MR, eps=eps, 
-                                                            frozenAtThroat=frozenAtThroat)
+                                        frozenAtThroat=frozenAtThroat, min_fraction=min_fraction)
         return molWtD, moleFracD
         
     def get_Chamber_H(self, Pc=100.0, MR=1.0, eps=40.0):
